<?php
namespace Modules\Fornecimento\Modules\Relatorios\Controllers;

use Zeedhi\Framework\Report\ReportService;
use Zeedhi\Framework\DTO;
use Zeedhi\Framework\DTO\Response\Error;
use Modules\Fornecimento\Modules\Relatorios\Services\Sup01900ProdutosCotadosService;

class Sup01900ProdutosCotadosController extends \Zeedhi\Framework\Controller\Report
{
    protected $qr2Strategy;
    protected $environment;
    protected $newCode;
    protected $birtStrategy;
    
    public function __construct($reportService, $qr2Strategy, $environment, Sup01900ProdutosCotadosService $service, $newCode, $connection, $birtStrategy)
    {
        $this->service           = $service;
        $this->qr2Strategy       = $qr2Strategy;
        $this->reportService     = $reportService;
        $this->environment       = $environment;
        $this->newCode           = $newCode;
        $this->connection        = $connection;
        $this->birtStrategy      = $birtStrategy;
        
    }
    
    public function beforeProcessReport(DTO\Request\Row $request, DTO\Response $response)
    {
        try {
            $row = $request->getRow();
            $this->birtStrategy->setReportFormat(strtolower($row['QR2TYPE']));
            $nomeRelatorio = explode(".",$row['REPORT']);
            $row['__report_name'] = $nomeRelatorio[0];
            $params = array(
                "CDFILIAL" => $this->environment->getCdFilial()
            );
            $row['CDFILIAL'] = $this->service->getFilial($params);
            $row['NRORG'] = $this->environment->getNrOrg();
            if($nomeRelatorio[1] == "BIRT"){
                if($row['CDFORNECED'] != 'T'){
                    $nrlistaForn = $this->criarListaValores($row['CDFORNECED']);
                    $row['CDFORNECED'] = "_NRLISTA=".$nrlistaForn;
                } 
                if($row['CDREGIAO'] != 'T'){
                    $nrlistaReg = $this->criarListaValores($row['CDREGIAO']);
                    $row['CDREGIAO'] = "_NRLISTA=".$nrlistaReg;
                }
            }
            $this->qr2Strategy->setQr2Type($row['QR2TYPE']);
        } catch (Exception $e) {
            $response->setError(Error::factoryFromException($e, $e->getMessage(), $e->getCode()));
        }
    
        $this->stNomeRel = $this->getReportName($row);
        $this->reportMapping[$this->stNomeRel] =
            array (
                'strategy' => $row['STRATEGY'],
                'parameterMapping' =>
                    array (
                        "CDFILIAL"      => "P_CDFILIAL",
                        "DTINI"         => "P_DTINI",
                        "DTFIN"         => "P_DTFIN",
                        "DTINICIAL"     => "P_DTINICIAL",
                        "DTFINAL"       => "P_DTFINAL",
                        "CDARVPRODINI"  => "P_CDINI",
                        "CDARVPRODFIN"  => "P_CDFIN",
                        "CDFORNECED"    => "L_CDFORNECED",
                        "CDREGIAO"      => "L_CDREGIAO",
                        "NRORG"         => "P_NRORG"
                    ),
            );
     }
     
     protected function criarListaValores($lista){
        $nrlista = $this->newCode->getCodeByTableName('LISTA', $this->environment->getNrOrg());
        $valores = explode('_',$lista);
        try{
            foreach($valores as $key){
                $this->insertLista($nrlista, $key);
            }
            return $nrlista;
        } catch(\Exception $e){
            throw $e;
        }
     }

     public function insertLista($nrlista, $cdlista) {
        $params = array(
            "NRLISTA" => $nrlista,
            "CDLISTA" => $cdlista
        );

        $sql = "INSERT INTO LISTA (NRLISTA, CDLISTA) VALUES (:NRLISTA, :CDLISTA)";
        $query = $this->connection->prepare($sql);
        $query->execute($params);
    }
}
