/******************************************************************************/
/* Sistemas Integrados TECNISA                                                */
/*                                                                            */
/* Compras e Suprimentos                                                      */
/*                                                                            */
/******************************************************************************/
/*                                                                            */
/* Nome: 8380_SUPSTP_INCLUI_ITEMCOL_TODOS                                     */
/*                                                                            */
/* Descrio:                                                                 */
/*    Seleciona os dados para incluso dos itens de uma nova cotao.         */
/*                                                                            */
/* Criao:                                                                   */
/*   19/05/2000 - Adriano de Arajo                                           */
/*                                                                            */
/* Manutenes:                                                               */
/*   /  /   -                                                                 */
/*                                                                            */
/******************************************************************************/

IF EXISTS (SELECT * FROM sysobjects O, sysusers U
          WHERE
            o.name = 'INCLUI_ITEMCOL_TODOS'  and
            type = 'P'                  and
            u.uid = o.uid               and
            u.name = USER)

   DROP PROCEDURE INCLUI_ITEMCOL_TODOS;
GO

CREATE PROCEDURE INCLUI_ITEMCOL_TODOS
                      @P_CDFILIAL     VARCHAR(4),
                      @P_CDFILIPROC   VARCHAR(4),
                      @P_NRCOLEPRECO  VARCHAR(10),
                      @P_DTINI        DATETIME,
                      @P_DTFIN        DATETIME,
                      @P_PRODINI      VARCHAR(20)   = NULL,
                      @P_PRODFIN      VARCHAR(20)   = NULL,
                      @P_CDREGIAO     VARCHAR(3000) = NULL,
                      @P_CDFORNECED   VARCHAR(3000) = NULL,
                      @P_CDMARCA      VARCHAR(3000) = NULL,
                      @P_CONSIST      VARCHAR(3000) = NULL,
                      @P_IDULTPREC    VARCHAR(1) = 'N',
                      @P_CDOPERINCL   VARCHAR(12),
                      @P_ROWSAFFECT   VARCHAR(1) OUTPUT

/*P_CONSIST:
  -> 0 = PRODCOMP
  -> 1 = QUALIFICACAO FORNECEDOR
  -> 2 = QFOPRODFORN
  -> 3 = QFOMARCPROD
*/

AS

DECLARE @V_CDOPERADOR VARCHAR(12);
DECLARE @V_DTCOL      DATETIME;
DECLARE @V_DTINIVALCOL DATETIME;
DECLARE @V_DTFINVALCOL DATETIME;

DECLARE @V_PRODFORN_CDPRODUTO    VARCHAR(10);
DECLARE @V_PRODFORN_CDPRODESTO   VARCHAR(10);
DECLARE @V_PRODFORN_CDFORNECED   VARCHAR(21);
DECLARE @V_PRODFORN_VRPEDESCFORN NUMERIC(10,2);
DECLARE @V_PRODFORN_IDTPFRETFORN VARCHAR(1);
DECLARE @V_PRODFORN_CDMARCA      VARCHAR(5);
DECLARE @V_PRODFORN_CDREGIAO     VARCHAR(3);
DECLARE @V_PRODFORN_CDARVPROD    VARCHAR(20);

DECLARE @V_QTACOMPRAR  NUMERIC(10,3);

DECLARE @V_TREGIAO   VARCHAR(1);
DECLARE @V_TPRODUTO  VARCHAR(1);
DECLARE @V_TFORNECED VARCHAR(1);

DECLARE @V_QFOMARPROD  INT;
DECLARE @V_IDMARSEMQUA INT;
DECLARE @V_QFOPRODFORN INT;
DECLARE @V_QFOFORN     INT;

DECLARE @V_CTROWS  INT;
DECLARE @V_CTFORN  INT;
DECLARE @V_CTPRODS INT;

DECLARE @V_SQL_ROWCOUNT INT;
DECLARE @V_CONSIST VARCHAR(2000);
DECLARE @V_CTITEMCOLE INT;
DECLARE @V_ULTPRECO   DOUBLE PRECISION;

DECLARE @V_PGTO_CDPRODUTO    VARCHAR(10);
DECLARE @V_PGTO_CDFORMPGTO   VARCHAR(2);
DECLARE @V_PGTO_IDTPFORPGPRF VARCHAR(1);
DECLARE @V_PGTO_NRPARCPGTPRF NUMERIC(2);
DECLARE @V_PGTO_NRDIAPGFIPRF NUMERIC(2);
DECLARE @V_PGTO_IDUTDIAPGPRF VARCHAR(1);

DECLARE @V_PGTO_IDTPFORPGTFO VARCHAR(1);
DECLARE @V_PGTO_NRPARCPGTOFO NUMERIC(2);
DECLARE @V_PGTO_NRDIAPGFIXFO NUMERIC(2);
DECLARE @V_PGTO_IDUTDIAPGTFO VARCHAR(1);
DECLARE @V_PGTO_IDTPDESCFORN VARCHAR(1);
DECLARE @V_PGTO_VRPEDESCFORN NUMERIC(10, 2);
DECLARE @V_PGTO_IDTPFRETFORN VARCHAR(1);

DECLARE @V_CDEMPRESA  VARCHAR(2);
DECLARE @V_INSCESTA   VARCHAR(16);

DECLARE @V_IDCONSPRSOL VARCHAR(1);

BEGIN
  SET @V_CONSIST = @P_CONSIST;
  SET @V_SQL_ROWCOUNT = 0;
  SET @V_CTROWS = 0;
  SET @P_ROWSAFFECT = 'N';
  IF @P_CDREGIAO IS NULL
  BEGIN
     SET @V_TREGIAO = 'T';
  END;
  IF (@P_PRODINI IS NULL) AND (@P_PRODFIN IS NULL)
  BEGIN
     SET @V_TPRODUTO = 'T';
  END;
  IF @P_CDFORNECED IS NULL
  BEGIN
     SET @V_TFORNECED = 'T';
  END;
  IF @V_CONSIST IS NULL BEGIN
     SET @V_CONSIST = ' ';
  END;

  SELECT
   @V_CDOPERADOR  = CDOPERADOR,
   @V_DTCOL       = DTCOLEPREC,
   @V_DTINIVALCOL = DTINIVALCOL,
   @V_DTFINVALCOL = DTFINVALCOL
  FROM
   COLETAPR
  WHERE
   CDFILIAL    = @P_CDFILIAL AND
   NRCOLEPRECO = @P_NRCOLEPRECO;

  SELECT
    @V_IDCONSPRSOL = ISNULL(IDCONSPRSOL, 'N')
  FROM
     PARASUPRI
  WHERE
     CDFILIAL = @P_CDFILIAL;

  DECLARE C_PRODFORN CURSOR FOR
   (SELECT
      PRODFORNCOMP.CDPRODCOMPL AS CDPRODUTO,
      PRODFORNCOMP.CDFORNECED,
      CASE FORN_REG.IDTPDESCFORN
         WHEN 'C' THEN FORN_REG.VRPEDESCFORN
         ELSE 0
      END AS VRPEDESCFORN,
      PRODUTO.CDPRODESTO,
      FORN_REG.IDTPFRETFORN,
      ISNULL(MARCPRODCOMP.CDMARCA, PARASUPRI.CDMARCA) AS CDMARCA,
      FORN_REG.CDREGIAO,
      PRODUTO.CDARVPROD
    FROM
      PRODUTO,
      FILIAL FILI,
      PRODFORNCOMP LEFT JOIN MARCPRODCOMP ON
                      PRODFORNCOMP.CDPRODCOMPL = MARCPRODCOMP.CDPRMARCOMPL AND
                      (CHARINDEX(MARCPRODCOMP.CDMARCA, ISNULL(@P_CDMARCA, MARCPRODCOMP.CDMARCA)) <> 0),
      FORN_REG,
      PARASUPRI
    WHERE
      PRODFORNCOMP.CDPRODCOMPL = PRODUTO.CDPRODUTO AND
      PARASUPRI.CDFILIAL = @P_CDFILIAL AND
      ISNULL(PARASUPRI.IDUTLPROCMP, 'N') = 'S' AND
      PRODUTO.CDPRODUTO <> PRODUTO.CDPRODESTO AND
      ((PRODUTO.CDARVPROD BETWEEN @P_PRODINI AND @P_PRODFIN) OR (@V_TPRODUTO = 'T')) AND
      (CHARINDEX(FORN_REG.CDFORNECED, @P_CDFORNECED) <> 0 OR @V_TFORNECED = 'T')AND
      (CHARINDEX(FORN_REG.CDREGIAO, @P_CDREGIAO) <> 0 OR @V_TREGIAO = 'T')AND
      FORN_REG.CDFORNECED = PRODFORNCOMP.CDFORNECED  AND
      ISNULL(MARCPRODCOMP.CDMARCA, PARASUPRI.CDMARCA) IS NOT NULL AND
      (ISNULL(PRODUTO.IDPRODATIVPR, 'S')= 'S') AND

      FILI.CDFILIAL = @P_CDFILIPROC AND
      ((FILI.IDFUNCAOFILI IS NULL) OR (FILI.IDFUNCAOFILI = 'O'))

    UNION ALL

    SELECT
      PRODFORNCOMP.CDPRODCOMPL AS CDPRODUTO,
      PRODFORNCOMP.CDFORNECED,
      CASE FORN_REG.IDTPDESCFORN
         WHEN 'C' THEN FORN_REG.VRPEDESCFORN
         ELSE 0
      END AS VRPEDESCFORN,
      PRODUTO.CDPRODESTO,
      FORN_REG.IDTPFRETFORN,
      ISNULL(MARCPRODCOMP.CDMARCA, PARASUPRI.CDMARCA) AS CDMARCA,
      FORN_REG.CDREGIAO,
      PRODUTO.CDARVPROD
    FROM
      PRODUTO,
      FILIAL FILI,
      PRODFORNCOMP LEFT JOIN MARCPRODCOMP ON
                      PRODFORNCOMP.CDPRODCOMPL = MARCPRODCOMP.CDPRMARCOMPL AND
                      (CHARINDEX(MARCPRODCOMP.CDMARCA, ISNULL(@P_CDMARCA, MARCPRODCOMP.CDMARCA)) <> 0),
      FORN_REG,
      PARASUPRI
    WHERE
      PARASUPRI.CDFILIAL = @P_CDFILIAL AND
      ISNULL(PARASUPRI.IDUTLPROCMP, 'N') = 'N' AND
      ((PRODUTO.CDARVPROD BETWEEN @P_PRODINI AND @P_PRODFIN) OR (@V_TPRODUTO = 'T')) AND
      (CHARINDEX(FORN_REG.CDFORNECED, @P_CDFORNECED) <> 0 OR @V_TFORNECED = 'T')AND
      (CHARINDEX(FORN_REG.CDREGIAO, @P_CDREGIAO) <> 0 OR @V_TREGIAO   = 'T')AND
      FORN_REG.CDFORNECED = PRODFORNCOMP.CDFORNECED  AND
      PRODUTO.CDPRODUTO = PRODFORNCOMP.CDPRODCOMPL AND
      ISNULL(MARCPRODCOMP.CDMARCA, PARASUPRI.CDMARCA) IS NOT NULL AND
      (ISNULL(PRODUTO.IDPRODATIVPR, 'S')= 'S') AND

      FILI.CDFILIAL = @P_CDFILIPROC AND
      ((FILI.IDFUNCAOFILI IS NULL) OR (FILI.IDFUNCAOFILI = 'O'))

   UNION ALL

   SELECT
      PRODFORNCOMP.CDPRODCOMPL AS CDPRODUTO,
      PRODFORNCOMP.CDFORNECED,
      CASE FORN_REG.IDTPDESCFORN
         WHEN 'C' THEN FORN_REG.VRPEDESCFORN
         ELSE 0
      END AS VRPEDESCFORN,
      PRODUTO.CDPRODESTO,
      FORN_REG.IDTPFRETFORN,
      ISNULL(MARCPRODCOMP.CDMARCA, PARASUPRI.CDMARCA) AS CDMARCA,
      FORN_REG.CDREGIAO,
      PRODUTO.CDARVPROD
    FROM
      PRODUTO,
      PRODFORNCOMP LEFT JOIN MARCPRODCOMP ON
                      PRODFORNCOMP.CDPRODCOMPL = MARCPRODCOMP.CDPRMARCOMPL AND
                      (CHARINDEX(MARCPRODCOMP.CDMARCA, ISNULL(@P_CDMARCA, MARCPRODCOMP.CDMARCA)) <> 0),
      FORN_REG,
      PARASUPRI,

    (SELECT
        PARAMPRODSUP.CDREGIAO,
        PARAMPRODSUP.CDPRODUTO
     FROM
        PARAMPRODSUP,
        FILIAL
     WHERE
        FILIAL.CDFILIAL = @P_CDFILIPROC AND
        FILIAL.IDFUNCAOFILI = 'C' AND
        FILIAL.CDFILIAL = PARAMPRODSUP.CDFILICTRL AND
        PARAMPRODSUP.IDFILINEGCOR = 'S'

     UNION ALL

     SELECT
        PARAMPRODSUP.CDREGIAO,
        PARAMPRODSUP.CDPRODUTO
     FROM
        PARAMPRODSUP,
        FILIAL
     WHERE
        FILIAL.CDFILIAL = @P_CDFILIPROC AND
        FILIAL.IDFUNCAOFILI = 'R' AND
        FILIAL.CDFILIAL = PARAMPRODSUP.CDFILICTRL AND
        PARAMPRODSUP.IDFILINEGREG = 'S') PARAMPRODSUP
    WHERE
      PRODFORNCOMP.CDPRODCOMPL = PRODUTO.CDPRODUTO AND
      PARASUPRI.CDFILIAL = @P_CDFILIAL AND
      ISNULL(PARASUPRI.IDUTLPROCMP, 'N') = 'S' AND
      PRODUTO.CDPRODUTO <> PRODUTO.CDPRODESTO AND
      ((PRODUTO.CDARVPROD BETWEEN @P_PRODINI AND @P_PRODFIN) OR (@V_TPRODUTO = 'T')) AND
      (CHARINDEX(FORN_REG.CDFORNECED, @P_CDFORNECED) <> 0 OR @V_TFORNECED = 'T')AND
      (CHARINDEX(FORN_REG.CDREGIAO, @P_CDREGIAO) <> 0 OR @V_TREGIAO = 'T')AND
      FORN_REG.CDFORNECED = PRODFORNCOMP.CDFORNECED  AND
      ISNULL(MARCPRODCOMP.CDMARCA, PARASUPRI.CDMARCA) IS NOT NULL AND
      (ISNULL(PRODUTO.IDPRODATIVPR, 'S')= 'S') AND

      PARAMPRODSUP.CDPRODUTO = PRODUTO.CDPRODUTO AND
      PARAMPRODSUP.CDREGIAO = FORN_REG.CDREGIAO

    UNION ALL

    SELECT
      PRODFORNCOMP.CDPRODCOMPL AS CDPRODUTO,
      PRODFORNCOMP.CDFORNECED,
      CASE FORN_REG.IDTPDESCFORN
         WHEN 'C' THEN FORN_REG.VRPEDESCFORN
         ELSE 0
      END AS VRPEDESCFORN,
      PRODUTO.CDPRODESTO,
      FORN_REG.IDTPFRETFORN,
      ISNULL(MARCPRODCOMP.CDMARCA, PARASUPRI.CDMARCA) AS CDMARCA,
      FORN_REG.CDREGIAO,
      PRODUTO.CDARVPROD
    FROM
      PRODUTO,
      PRODFORNCOMP LEFT JOIN MARCPRODCOMP ON
                      PRODFORNCOMP.CDPRODCOMPL = MARCPRODCOMP.CDPRMARCOMPL AND
                      (CHARINDEX(MARCPRODCOMP.CDMARCA, ISNULL(@P_CDMARCA, MARCPRODCOMP.CDMARCA)) <> 0),
      FORN_REG,
      PARASUPRI,

    (SELECT
        PARAMPRODSUP.CDREGIAO,
        PARAMPRODSUP.CDPRODUTO
     FROM
        PARAMPRODSUP,
        FILIAL
     WHERE
        FILIAL.CDFILIAL = @P_CDFILIPROC AND
        FILIAL.IDFUNCAOFILI = 'C' AND
        FILIAL.CDFILIAL = PARAMPRODSUP.CDFILICTRL AND
        PARAMPRODSUP.IDFILINEGCOR = 'S'

     UNION ALL

     SELECT
        PARAMPRODSUP.CDREGIAO,
        PARAMPRODSUP.CDPRODUTO
     FROM
        PARAMPRODSUP,
        FILIAL
     WHERE
        FILIAL.CDFILIAL = @P_CDFILIPROC AND
        FILIAL.IDFUNCAOFILI = 'R' AND
        FILIAL.CDFILIAL = PARAMPRODSUP.CDFILICTRL AND
        PARAMPRODSUP.IDFILINEGREG = 'S') PARAMPRODSUP
    WHERE
      PARASUPRI.CDFILIAL = @P_CDFILIAL AND
      ISNULL(PARASUPRI.IDUTLPROCMP, 'N') = 'N' AND
      ((PRODUTO.CDARVPROD BETWEEN @P_PRODINI AND @P_PRODFIN) OR (@V_TPRODUTO = 'T')) AND
      (CHARINDEX(FORN_REG.CDFORNECED, @P_CDFORNECED) <> 0 OR @V_TFORNECED = 'T')AND
      (CHARINDEX(FORN_REG.CDREGIAO, @P_CDREGIAO) <> 0 OR @V_TREGIAO   = 'T')AND
      FORN_REG.CDFORNECED = PRODFORNCOMP.CDFORNECED  AND
      PRODUTO.CDPRODUTO = PRODFORNCOMP.CDPRODCOMPL AND
      ISNULL(MARCPRODCOMP.CDMARCA, PARASUPRI.CDMARCA) IS NOT NULL AND
      (ISNULL(PRODUTO.IDPRODATIVPR, 'S')= 'S') AND

      PARAMPRODSUP.CDPRODUTO = PRODUTO.CDPRODUTO AND
      PARAMPRODSUP.CDREGIAO = FORN_REG.CDREGIAO)

  OPEN C_PRODFORN;
  FETCH NEXT FROM C_PRODFORN INTO @V_PRODFORN_CDPRODUTO, @V_PRODFORN_CDFORNECED,
                                  @V_PRODFORN_VRPEDESCFORN,
                                  @V_PRODFORN_CDPRODESTO, @V_PRODFORN_IDTPFRETFORN, @V_PRODFORN_CDMARCA, @V_PRODFORN_CDREGIAO,
                                  @V_PRODFORN_CDARVPROD


  WHILE (@@FETCH_STATUS = 0)
  BEGIN
     IF CHARINDEX('0', @V_CONSIST) <> 0 BEGIN
        SET @V_CTPRODS = 0;
        SELECT
          @V_CTPRODS = COUNT(*)
        FROM
          PRODCOMP, PRODUTO
        WHERE
           (PRODCOMP.CDPRODUTO  = PRODUTO.CDPRODUTO) AND
           (PRODCOMP.CDOPERADOR = @V_CDOPERADOR) AND
           (@V_PRODFORN_CDARVPROD LIKE PRODUTO.CDARVPROD + '%');
     END
     ELSE BEGIN
        SET @V_CTPRODS = 1;
     END;

     IF @V_CTPRODS > 0 BEGIN

       IF CHARINDEX('1', @V_CONSIST) <> 0 BEGIN
          SET @V_QFOFORN = 0;
          SELECT @V_QFOFORN = COUNT(*)    /* NOT EXISTS */
          FROM QUALIFICACAO, PARASUPRI, FORNECEDOR
          WHERE (FORNECEDOR.CDFORNECED     = @V_PRODFORN_CDFORNECED)          AND
                (FORNECEDOR.CDQUALIF       = QUALIFICACAO.CDQUALIF) AND
                (PARASUPRI.CDFILIAL        = @P_CDFILIAL)            AND
                (FORNECEDOR.IDFORNAUTO     = 'N')                   AND
                ((QUALIFICACAO.IDPERCOTCMP = '2')                   OR
                 ((PARASUPRI.IDULTIDTVALQ  = 'D'                    AND
                   @V_DTFINVALCOL > FORNECEDOR.DTVALQUALIF)    OR
                 (PARASUPRI.IDULTIDTVALQ = 'M'                      AND
                  @V_DTFINVALCOL > DATEADD(MM, 1, FORNECEDOR.DTVALQUALIF) - DAY(DATEADD(MM, 1, FORNECEDOR.DTVALQUALIF)) )));
       END
       ELSE BEGIN
          SET @V_QFOFORN = 0;
       END;

       IF CHARINDEX('3', @V_CONSIST) <> 0 BEGIN
         SET @V_QFOMARPROD = 0;
         SELECT
            @V_QFOMARPROD = COUNT(*) /* NOT EXISTS */
         FROM
            QFOMARPROD,
            PARASUPRI
         WHERE
           PARASUPRI.CDFILIAL = @P_CDFILIAL  AND
           (QFOMARPROD.CDPRODUTO = @V_PRODFORN_CDPRODUTO) AND
           (QFOMARPROD.CDMARCA   = @V_PRODFORN_CDMARCA  ) AND
           ((QFOMARPROD.IDAPRMARPRO = 'N' AND QFOMARPROD.IDAUTMARPRO = 'N') OR
            ((QFOMARPROD.IDAPRMARPRO = 'S') AND
               ((PARASUPRI.IDULTIDTVALQ = 'M' AND
                 @V_DTCOL > DATEADD(MM, 1, QFOMARPROD.DTVALAPROVA) - DAY(DATEADD(MM, 1, QFOMARPROD.DTVALAPROVA)) ) OR
                (PARASUPRI.IDULTIDTVALQ = 'D' AND
                 @V_DTCOL > QFOMARPROD.DTVALAPROVA)) ) );

         SET @V_IDMARSEMQUA = 0;
         SELECT
           @V_IDMARSEMQUA = COUNT(*)
         FROM
           QFOMARPROD
         WHERE
           QFOMARPROD.CDPRODUTO = @V_PRODFORN_CDPRODUTO AND
           QFOMARPROD.CDMARCA   = @V_PRODFORN_CDMARCA;

         SET @V_IDMARSEMQUA = 0;
         IF @V_IDMARSEMQUA = 0 BEGIN
           SELECT
             @V_IDMARSEMQUA = COUNT(*)
           FROM
             PARASUPRI
           WHERE
             PARASUPRI.CDFILIAL    = @P_CDFILIAL AND
             (PARASUPRI.IDMARSEMQUA = 'N' OR PARASUPRI.IDMARSEMQUA IS NULL);
         END;
       END
       ELSE BEGIN
          SET @V_QFOMARPROD  = 0;
          SET @V_IDMARSEMQUA = 1;
       END;

       IF CHARINDEX('2', @V_CONSIST) <> 0 BEGIN
         SET @V_QFOPRODFORN = 0;
         SELECT
            @V_QFOPRODFORN = COUNT(*)  /* NOT EXISTS */
         FROM
            QFOPRODFORN,
            PARASUPRI
         WHERE
           PARASUPRI.CDFILIAL = @P_CDFILIAL  AND
           (QFOPRODFORN.CDPRODUTO = @V_PRODFORN_CDPRODUTO) AND
           (QFOPRODFORN.CDFORNECED= @V_PRODFORN_CDFORNECED) AND
           ((QFOPRODFORN.IDFORNAPROV = 'N' AND QFOPRODFORN.IDFORNAUTOR = 'N') OR
            ((QFOPRODFORN.IDFORNAPROV = 'S') AND
               ((PARASUPRI.IDULTIDTVALQ = 'M' AND
                 @V_DTCOL > DATEADD(MM, 1, QFOPRODFORN.DTVALPRFORN) - DAY(DATEADD(MM, 1, QFOPRODFORN.DTVALPRFORN)) ) OR
                (PARASUPRI.IDULTIDTVALQ = 'D' AND
                 @V_DTCOL > QFOPRODFORN.DTVALPRFORN)) ) );
       END
       ELSE BEGIN
          SET @V_QFOPRODFORN = 0;
       END;

       IF (@V_QFOMARPROD  = 0) AND
          (@V_IDMARSEMQUA > 0) AND
          (@V_QFOPRODFORN = 0) AND
          (@V_QFOFORN     = 0) BEGIN
         SET @V_CTITEMCOLE = 0;
         SELECT @V_CTITEMCOLE = COUNT(*)
         FROM ITEMCOLE
         WHERE
            ITEMCOLE.CDFILIAL = @P_CDFILIAL AND
            ITEMCOLE.NRCOLEPRECO = @P_NRCOLEPRECO AND
            ITEMCOLE.CDMARCA = @V_PRODFORN_CDMARCA AND
            ITEMCOLE.CDREGIAO = @V_PRODFORN_CDREGIAO AND
            ITEMCOLE.CDFORNECED = @V_PRODFORN_CDFORNECED AND
            ITEMCOLE.CDPRODUTO = @V_PRODFORN_CDPRODUTO;
         IF @V_CTITEMCOLE = 0 BEGIN
            SET @V_QTACOMPRAR = 0;

            IF @V_IDCONSPRSOL = 'S' BEGIN
               SET @V_QTACOMPRAR = NULL;
               SELECT  /* Buscando a quantidade a comprar considerando o parametro IDCONSPRSOL da PARASUPRI */
                  @V_QTACOMPRAR = SUM(PRODACOMPRAR.QTACOMPRAR)
               FROM
                  (SELECT
                      COMP.CDFILIAL, COMP.DTPROGENTR,
                      COMP.CDPRODUTO,
                      ROUND((COMP.QTDECOMP-ISNULL(JACOMP.QTDECOMP,0)) / COMP.VRFATOCONV, 5) AS QTACOMPRAR
                   FROM
                      (SELECT
                        ITEMSOLI.CDFILSOLI AS CDFILIAL,
                        ITEMSOLI.DTPROGENTR,
                        PRODUTO.CDPRODUTO,
                        PRODUTO.CDPRODESTO,
                        PRODUTO.VRFATOCONV,
                        SUM(ITEMSOLI.QTSOLIPROD*PRODUTO.VRFATOCONV) AS QTDECOMP
                       FROM
                        PRODUTO, ITEMSOLI
                       WHERE
                        (ITEMSOLI.IDITMCONS = 'N') AND
                        (ITEMSOLI.CDPRODUTO = PRODUTO.CDPRODUTO) AND
                        (PRODUTO.CDPRODUTO = @V_PRODFORN_CDPRODUTO) AND
                        (ITEMSOLI.DTPROGENTR BETWEEN @P_DTINI AND @P_DTFIN) AND
                        (ISNULL(ITEMSOLI.IDSOLIAPROV,'S') = 'S')
                       GROUP BY
                        ITEMSOLI.CDFILSOLI,
                        ITEMSOLI.DTPROGENTR,
                        PRODUTO.CDPRODUTO,
                        PRODUTO.CDPRODESTO,
                        PRODUTO.VRFATOCONV) COMP

                     LEFT JOIN

                      (SELECT
                        ITEMAUTF.CDFILDEST AS CDFILIAL,
                        ITEMAUTF.DTENTRITMSOL,
                        PRODUTO.CDPRODESTO,
                        SUM(ITEMAUTF.QTPROGENTAF*PRODUTO.VRFATOCONV) AS QTDECOMP
                       FROM
                        PRODUTO, ITEMAUTF, AUTOFORNE
                       WHERE
                       (AUTOFORNE.CDFILDEST = ITEMAUTF.CDFILDEST) AND
                       (AUTOFORNE.CDFILLANC = ITEMAUTF.CDFILLANC) AND
                       (AUTOFORNE.NRAUTOFORN = ITEMAUTF.NRAUTOFORN) AND
                       (ITEMAUTF.CDPRODUTO = PRODUTO.CDPRODUTO) AND
                       (PRODUTO.CDPRODESTO = @V_PRODFORN_CDPRODESTO) AND
                       (AUTOFORNE.IDSITUATUAAF IS NULL) AND
                       (AUTOFORNE.IDAFFORALIM = 'N') AND
                       (AUTOFORNE.IDAUTOFORNEX = 'N') AND
                       (ISNULL(AUTOFORNE.IDBAIXAAF, '0') <> '5')
                      GROUP BY
                       ITEMAUTF.CDFILDEST,
                       ITEMAUTF.DTENTRITMSOL,
                       PRODUTO.CDPRODESTO) JACOMP
                     ON
                      COMP.CDFILIAL = JACOMP.CDFILIAL AND
                      COMP.DTPROGENTR = JACOMP.DTENTRITMSOL AND
                      COMP.CDPRODESTO = JACOMP.CDPRODESTO
                   WHERE
                      ROUND((COMP.QTDECOMP-ISNULL(JACOMP.QTDECOMP,0)) / COMP.VRFATOCONV, 5) > 0)PRODACOMPRAR,
                  FILIAL
               WHERE
                  PRODACOMPRAR.CDFILIAL  = FILIAL.CDFILIAL AND
                  PRODACOMPRAR.CDPRODUTO = @V_PRODFORN_CDPRODUTO AND
                  ((FILIAL.CDFILCENTCMP = @P_CDFILIAL) OR
                  (FILIAL.CDFILIAL = @P_CDFILIAL AND FILIAL.CDFILCENTCMP IS NULL)) AND
                   FILIAL.CDREGIAO  = @V_PRODFORN_CDREGIAO;
            END
            ELSE BEGIN
               SET @V_QTACOMPRAR = NULL;
               SELECT  /* Buscando a quantidade a comprar */
                  @V_QTACOMPRAR = SUM(PRODACOMPRAR.QTACOMPRAR)
               FROM
                  (SELECT
                      COMP.CDFILIAL, COMP.DTPROGENTR,
                      COMP.CDPRODUTO,
                      ROUND(COMP.QTDECOMP-ISNULL(JACOMP.QTDECOMP/COMP.VRFATOCONV,0), 5) AS QTACOMPRAR
                   FROM
                      (SELECT
                        ITEMSOLI.CDFILSOLI AS CDFILIAL,
                        ITEMSOLI.DTPROGENTR,
                        ESTOQUE.CDPRODUTO,
                        ESTOQUE.CDPRODESTO,
                        ESTOQUE.VRFATOCONV,
                        SUM(ITEMSOLI.QTSOLIPROD*PRODUTO.VRFATOCONV/ESTOQUE.VRFATOCONV) AS QTDECOMP
                       FROM
                        PRODUTO ESTOQUE, PRODUTO, ITEMSOLI
                       WHERE
                        (ITEMSOLI.IDITMCONS = 'N') AND
                        (ITEMSOLI.CDPRODUTO = PRODUTO.CDPRODUTO) AND
                        (PRODUTO.CDPRODESTO = ESTOQUE.CDPRODESTO) AND
                        (ITEMSOLI.DTPROGENTR BETWEEN @P_DTINI AND @P_DTFIN) AND
                        (ESTOQUE.CDPRODESTO = @V_PRODFORN_CDPRODESTO) AND
                        (ISNULL(ITEMSOLI.IDSOLIAPROV,'S') = 'S')
                       GROUP BY
                        ITEMSOLI.CDFILSOLI,
                        ITEMSOLI.DTPROGENTR,
                        ESTOQUE.CDPRODUTO,
                        ESTOQUE.CDPRODESTO,
                        ESTOQUE.VRFATOCONV) COMP

                     LEFT JOIN

                      (SELECT
                        ITEMAUTF.CDFILDEST AS CDFILIAL,
                        ITEMAUTF.DTENTRITMSOL,
                        PRODUTO.CDPRODESTO,
                        SUM(ITEMAUTF.QTPROGENTAF*PRODUTO.VRFATOCONV) AS QTDECOMP
                       FROM
                        PRODUTO, ITEMAUTF, AUTOFORNE
                       WHERE
                       (AUTOFORNE.CDFILDEST = ITEMAUTF.CDFILDEST) AND
                       (AUTOFORNE.CDFILLANC = ITEMAUTF.CDFILLANC) AND
                       (AUTOFORNE.NRAUTOFORN = ITEMAUTF.NRAUTOFORN) AND
                       (ITEMAUTF.CDPRODUTO = PRODUTO.CDPRODUTO) AND
                       (PRODUTO.CDPRODESTO = @V_PRODFORN_CDPRODESTO) AND
                       (AUTOFORNE.IDSITUATUAAF IS NULL) AND
                       (AUTOFORNE.IDAFFORALIM = 'N') AND
                       (AUTOFORNE.IDAUTOFORNEX = 'N') AND
                       (ISNULL(AUTOFORNE.IDBAIXAAF, '0') <> '5')
                      GROUP BY
                       ITEMAUTF.CDFILDEST,
                       ITEMAUTF.DTENTRITMSOL,
                       PRODUTO.CDPRODESTO) JACOMP
                     ON
                      COMP.CDFILIAL = JACOMP.CDFILIAL AND
                      COMP.DTPROGENTR = JACOMP.DTENTRITMSOL AND
                      COMP.CDPRODESTO = JACOMP.CDPRODESTO
                   WHERE
                      ROUND(COMP.QTDECOMP-ISNULL(JACOMP.QTDECOMP/COMP.VRFATOCONV,0), 5) > 0)PRODACOMPRAR,
                  FILIAL
               WHERE
                  PRODACOMPRAR.CDFILIAL  = FILIAL.CDFILIAL AND
                  PRODACOMPRAR.CDPRODUTO = @V_PRODFORN_CDPRODUTO AND
                  ((FILIAL.CDFILCENTCMP = @P_CDFILIAL) OR
                  (FILIAL.CDFILIAL = @P_CDFILIAL AND FILIAL.CDFILCENTCMP IS NULL)) AND
                   FILIAL.CDREGIAO  = @V_PRODFORN_CDREGIAO;
            END;
            SET @V_ULTPRECO = NULL;
            IF @P_IDULTPREC = 'S' BEGIN
               SET @V_ULTPRECO = NULL;
               SELECT @V_ULTPRECO = MIN(A.VRPRECUNIITM)
               FROM ITEMCOLE A
               WHERE
                  A.CDFILIAL = @P_CDFILIAL AND
                  A.CDMARCA = @V_PRODFORN_CDMARCA AND
                  A.CDREGIAO = @V_PRODFORN_CDREGIAO AND
                  A.CDFORNECED = @V_PRODFORN_CDFORNECED AND
                  A.CDPRODUTO = @V_PRODFORN_CDPRODUTO AND
                  A.VRPRECUNIITM > 0 AND
                  A.DTFINVALITM = (SELECT MAX(ITEMCOLE.DTFINVALITM)
                                   FROM ITEMCOLE
                                   WHERE
                                      ITEMCOLE.CDFILIAL = @P_CDFILIAL AND
                                      ITEMCOLE.CDMARCA = @V_PRODFORN_CDMARCA AND
                                      ITEMCOLE.CDREGIAO = @V_PRODFORN_CDREGIAO AND
                                      ITEMCOLE.CDFORNECED = @V_PRODFORN_CDFORNECED AND
                                      ITEMCOLE.VRPRECUNIITM > 0 AND
                                      ITEMCOLE.CDPRODUTO = @V_PRODFORN_CDPRODUTO);
            END;
            IF @V_ULTPRECO IS NULL BEGIN
               SET @V_ULTPRECO = 0;
            END;
            INSERT INTO ITEMCOLE
              (CDFILIAL, NRCOLEPRECO, DTINIVALITM,
               DTFINVALITM, VRPRECUNIITM, VRPRECECOITM,
                CDPRODUTO, CDMARCA, CDFORNECED, CDREGIAO, QTACMPITMCOL,
                VRPERDESITM, IDTIPFREITM, CDOPERINCL, DTINCLITMCOL)
            VALUES(@P_CDFILIAL, @P_NRCOLEPRECO, @P_DTINI,
                   @P_DTFIN, @V_ULTPRECO, 0, @V_PRODFORN_CDPRODUTO,
                   @V_PRODFORN_CDMARCA, @V_PRODFORN_CDFORNECED,
                   @V_PRODFORN_CDREGIAO, @V_QTACOMPRAR,
                   @V_PRODFORN_VRPEDESCFORN, @V_PRODFORN_IDTPFRETFORN,
                   @P_CDOPERINCL, GETDATE());
            SET @V_SQL_ROWCOUNT = 1;
         END;
         IF @V_ULTPRECO > 0 BEGIN
            SET @V_PGTO_CDPRODUTO    = NULL;
            SET @V_PGTO_CDFORMPGTO   = NULL;
            SET @V_PGTO_IDTPFORPGPRF = NULL;
            SET @V_PGTO_NRPARCPGTPRF = NULL;
            SET @V_PGTO_NRDIAPGFIPRF = NULL;
            SET @V_PGTO_IDUTDIAPGPRF = NULL;
            SELECT
               @V_PGTO_CDPRODUTO    = MAX(PRODUTO.CDARVPROD),
               @V_PGTO_CDFORMPGTO   = MAX(PRODFORN.CDFORMPGTO),
               @V_PGTO_IDTPFORPGPRF = MAX(PRODFORN.IDTPFORPGPRF),
               @V_PGTO_NRPARCPGTPRF = MAX(PRODFORN.NRPARCPGTPRF),
               @V_PGTO_NRDIAPGFIPRF = MAX(PRODFORN.NRDIAPGFIPRF),
               @V_PGTO_IDUTDIAPGPRF = MAX(PRODFORN.IDUTDIAPGPRF)
            FROM
              PRODFORN, PRODUTO
            WHERE
              PRODFORN.CDPRODUTO  = PRODUTO.CDPRODUTO     AND
              PRODFORN.CDFORNECED = @V_PRODFORN_CDFORNECED AND
              PRODUTO.CDARVPROD   = (SELECT MAX(PRODUTO.CDARVPROD)
                                     FROM PRODFORN, PRODUTO
                                     WHERE
                                     PRODFORN.CDPRODUTO   = PRODUTO.CDPRODUTO AND
                                     PRODFORN.CDFORNECED  = @V_PRODFORN_CDFORNECED AND
                                     @V_PRODFORN_CDARVPROD LIKE PRODUTO.CDARVPROD + '%');

            IF @V_PGTO_IDTPFORPGPRF IS NULL BEGIN
               SET @V_PGTO_CDFORMPGTO   = NULL;
               SET @V_PGTO_IDTPFORPGTFO = NULL;
               SET @V_PGTO_NRPARCPGTOFO = NULL;
               SET @V_PGTO_NRDIAPGFIXFO = NULL;
               SET @V_PGTO_IDUTDIAPGTFO = NULL;
               SET @V_PGTO_IDTPDESCFORN = NULL;
               SET @V_PGTO_VRPEDESCFORN = NULL;
               SET @V_PGTO_IDTPFRETFORN = NULL;
               SELECT
                 @V_PGTO_CDFORMPGTO   = CDFORMPGTO,
                 @V_PGTO_IDTPFORPGTFO = IDTPFORPGTFO,
                 @V_PGTO_NRPARCPGTOFO = NRPARCPGTOFO,
                 @V_PGTO_NRDIAPGFIXFO = NRDIAPGFIXFO,
                 @V_PGTO_IDUTDIAPGTFO = IDUTDIAPGTFO,
                 @V_PGTO_IDTPDESCFORN = IDTPDESCFORN,
                 @V_PGTO_VRPEDESCFORN = VRPEDESCFORN,
                 @V_PGTO_IDTPFRETFORN = IDTPFRETFORN
               FROM
                  FORNECEDOR
               WHERE
                  CDFORNECED = @V_PRODFORN_CDFORNECED;

               UPDATE ITEMCOLE
               SET
                  CDFORMPGTO   = @V_PGTO_CDFORMPGTO,
                  IDTPFOPGTCOL = @V_PGTO_IDTPFORPGTFO,
                  NRDIAPGFXCOL = @V_PGTO_NRDIAPGFIXFO,
                  NRPARCPGTCOL = @V_PGTO_NRPARCPGTOFO,
                  IDUTDIAPGCOL = @V_PGTO_IDUTDIAPGTFO
               WHERE
                  CDFILIAL    = @P_CDFILIAL   AND
                  NRCOLEPRECO = @P_NRCOLEPRECO AND
                  CDPRODUTO   = @V_PRODFORN_CDPRODUTO  AND
                  CDMARCA     = @V_PRODFORN_CDMARCA    AND
                  CDFORNECED  = @V_PRODFORN_CDFORNECED AND
                  CDREGIAO    = @V_PRODFORN_CDREGIAO;
               IF @V_PGTO_IDTPFORPGTFO = 'V' BEGIN
                  INSERT INTO PZOPGTITMCOL
                    (CDFILIAL, NRCOLEPRECO, CDFORNECED, CDPRODUTO,
                    CDMARCA, CDREGIAO, NRDIASPGTCOL, VRPERCPGTCOL)
                  SELECT
                     @P_CDFILIAL,
                     @P_NRCOLEPRECO,
                     @V_PRODFORN_CDFORNECED,
                     @V_PRODFORN_CDPRODUTO,
                     @V_PRODFORN_CDMARCA,
                     @V_PRODFORN_CDREGIAO,
                     PRAZOPGTFORN.NRDIASPGTOFO,
                     PRAZOPGTFORN.VRPERCPGTOFO
                  FROM
                     PRAZOPGTFORN
                  WHERE
                     PRAZOPGTFORN.CDFORNECED = @V_PRODFORN_CDFORNECED AND
                     NOT EXISTS (SELECT @P_CDFILIAL
                                 FROM PZOPGTITMCOL
                                 WHERE PZOPGTITMCOL.CDFILIAL    = @P_CDFILIAL AND
                                       PZOPGTITMCOL.NRCOLEPRECO = @P_NRCOLEPRECO AND
                                       PZOPGTITMCOL.CDFORNECED  = @V_PRODFORN_CDFORNECED AND
                                       PZOPGTITMCOL.CDPRODUTO   = @V_PRODFORN_CDPRODUTO AND
                                       PZOPGTITMCOL.CDMARCA     = @V_PRODFORN_CDMARCA AND
                                       PZOPGTITMCOL.CDREGIAO    = @V_PRODFORN_CDREGIAO);
               END;
            END
            ELSE BEGIN
               UPDATE ITEMCOLE
               SET
                  CDFORMPGTO   = @V_PGTO_CDFORMPGTO,
                  IDTPFOPGTCOL = @V_PGTO_IDTPFORPGPRF,
                  NRDIAPGFXCOL = @V_PGTO_NRDIAPGFIPRF,
                  NRPARCPGTCOL = @V_PGTO_NRPARCPGTPRF,
                  IDUTDIAPGCOL = @V_PGTO_IDUTDIAPGPRF
               WHERE
                  CDFILIAL    = @P_CDFILIAL   AND
                  NRCOLEPRECO = @P_NRCOLEPRECO AND
                  CDPRODUTO   = @V_PRODFORN_CDPRODUTO  AND
                  CDMARCA     = @V_PRODFORN_CDMARCA    AND
                  CDFORNECED  = @V_PRODFORN_CDFORNECED AND
                  CDREGIAO    = @V_PRODFORN_CDREGIAO;
               IF @V_PGTO_IDTPFORPGPRF = 'V' BEGIN
                  INSERT INTO PZOPGTITMCOL
                    (CDFILIAL, NRCOLEPRECO, CDFORNECED, CDPRODUTO,
                    CDMARCA, CDREGIAO, NRDIASPGTCOL, VRPERCPGTCOL)

                  SELECT
                     @P_CDFILIAL,
                     @P_NRCOLEPRECO,
                     @V_PRODFORN_CDFORNECED,
                     @V_PRODFORN_CDPRODUTO,
                     @V_PRODFORN_CDMARCA,
                     @V_PRODFORN_CDREGIAO,
                     PZOPGTPRFO.NRDIASPGPRFO,
                     PZOPGTPRFO.VRPERCPGPRFO
                  FROM
                     PZOPGTPRFO, PRODUTO
                  WHERE
                     PZOPGTPRFO.CDPRODUTO  = PRODUTO.CDPRODUTO     AND
                     PZOPGTPRFO.CDFORNECED = @V_PRODFORN_CDFORNECED AND
                     @V_PRODFORN_CDARVPROD LIKE PRODUTO.CDARVPROD + '%' AND
                     NOT EXISTS (SELECT @P_CDFILIAL
                                 FROM PZOPGTITMCOL
                                 WHERE PZOPGTITMCOL.CDFILIAL    = @P_CDFILIAL AND
                                       PZOPGTITMCOL.NRCOLEPRECO = @P_NRCOLEPRECO AND
                                       PZOPGTITMCOL.CDFORNECED  = @V_PRODFORN_CDFORNECED AND
                                       PZOPGTITMCOL.CDPRODUTO   = @V_PRODFORN_CDPRODUTO AND
                                       PZOPGTITMCOL.CDMARCA     = @V_PRODFORN_CDMARCA AND
                                       PZOPGTITMCOL.CDREGIAO    = @V_PRODFORN_CDREGIAO);
               END;
            END;

            SET @V_CDEMPRESA = NULL;
            SELECT
               @V_CDEMPRESA = MAX(CDEMPRESA)
            FROM
               EMITENTEAF,
               PRODUTO
            WHERE
               PRODUTO.CDPRODUTO = EMITENTEAF.CDPRODUTO AND
               CDFILIAL = @P_CDFILIAL AND
               @V_PRODFORN_CDARVPROD LIKE PRODUTO.CDARVPROD + '%';

            IF @V_CDEMPRESA IS NULL BEGIN
               SET @V_CDEMPRESA = NULL;
               SELECT
                  @V_CDEMPRESA = MAX(CDEMPRESA)
               FROM
                  PARCMPSUP
               WHERE
                  CDFILIAL = @P_CDFILIAL;
            END;

            SET @V_INSCESTA = NULL;
            SELECT
              @V_INSCESTA = MIN(INSCRESTAD.CDINSCESTA)
            FROM
              EMPRESA,
              INSCRMUNICIP,
              INSCRESTAD
            WHERE
              EMPRESA.CDEMPRESA = @V_CDEMPRESA            AND
              EMPRESA.CDEMPRESA = INSCRMUNICIP.CDEMPRESA AND
              EMPRESA.CDEMPRESA = INSCRESTAD.CDEMPRESA;

            SET @V_DTCOL = ISNULL(@V_DTCOL, CONVERT( DATETIME, CONVERT (VARCHAR, GETDATE(),103)));
            EXEC IMPOSTO_ITEMCOL @V_CDEMPRESA, @V_INSCESTA, @V_PRODFORN_CDFORNECED, @P_CDFILIAL,
                                 @P_NRCOLEPRECO, @V_PRODFORN_CDFORNECED, @V_PRODFORN_CDREGIAO, @V_PRODFORN_CDPRODUTO,
                                 @V_PRODFORN_CDMARCA, @V_DTCOL;

         END;
       END;

       SET @V_CTROWS = @V_CTROWS + @V_SQL_ROWCOUNT;
     END;

     FETCH NEXT FROM C_PRODFORN INTO @V_PRODFORN_CDPRODUTO, @V_PRODFORN_CDFORNECED,
                                  @V_PRODFORN_VRPEDESCFORN,
                                  @V_PRODFORN_CDPRODESTO, @V_PRODFORN_IDTPFRETFORN, @V_PRODFORN_CDMARCA, @V_PRODFORN_CDREGIAO,
                                  @V_PRODFORN_CDARVPROD
  END;
  CLOSE C_PRODFORN;
  DEALLOCATE C_PRODFORN;

  IF @V_CTROWS > 0 BEGIN
     SET @P_ROWSAFFECT = 'S';
  END;
END;
GO

-- VERSAO --
EXEC ATUVEROBJ 'INCLUI_ITEMCOL_TODOS','5.07.004';
GO

